import { View, Text, TouchableOpacity, StyleSheet, ScrollView, Modal, Linking } from 'react-native';
import { LinearGradient } from 'expo-linear-gradient';
import { Coins, Gift, AlertCircle } from 'lucide-react-native';
import { useState } from 'react';
import { useRouter } from 'expo-router';

const questions = [
  {
    id: 'age',
    number: 1,
    title: 'Qual a sua idade?',
    options: ['18-24', '25-34', '35-44', '45+'],
    reward: 52.55,
  },
  {
    id: 'social',
    number: 2,
    title: 'Com que frequência você usa as redes sociais?',
    options: ['Diariamente', 'Algumas vezes por semana', 'Raramente', 'Nunca'],
    reward: 48.92,
  },
  {
    id: 'shortVideos',
    number: 3,
    title: 'Você costuma assistir vídeos curtos?',
    options: ['Sim, frequentemente', 'Às vezes', 'Raramente', 'Não'],
    reward: 45.67,
  },
  {
    id: 'watchTime',
    number: 4,
    title: 'Quanto tempo por dia você passa assistindo vídeos?',
    options: ['Menos de 1 hora', '1-2 horas', '2-4 horas', 'Mais de 4 horas'],
    reward: 43.21,
  },
  {
    id: 'socialEarnings',
    number: 5,
    title: 'Você já ganhou dinheiro com redes sociais?',
    options: ['Sim, regularmente', 'Sim, ocasionalmente', 'Não, mas tenho interesse', 'Não tenho interesse'],
    reward: 41.89,
  },
  {
    id: 'contentPreference',
    number: 6,
    title: 'Qual tipo de conteúdo você mais gosta?',
    options: ['Humor', 'Educativo', 'Lifestyle', 'Música'],
    reward: 39.76,
  },
  {
    id: 'contentCreation',
    number: 7,
    title: 'Você costuma criar conteúdo para redes sociais?',
    options: ['Sim, diariamente', 'Algumas vezes por semana', 'Raramente', 'Nunca'],
    reward: 37.45,
  },
  {
    id: 'discovery',
    number: 8,
    title: 'Como você descobriu o Rewards?',
    options: ['Amigos', 'Anúncios', 'Redes sociais', 'Outros'],
    reward: 35.88,
  },
  {
    id: 'recommendation',
    number: 9,
    title: 'Você indicaria o app para amigos?',
    options: ['Definitivamente sim', 'Provavelmente sim', 'Talvez', 'Não'],
    reward: 33.92,
  },
  {
    id: 'mainGoal',
    number: 10,
    title: 'Qual seu objetivo principal no app?',
    options: ['Ganhar dinheiro', 'Entretenimento', 'Criar conteúdo', 'Conhecer pessoas'],
    reward: 31.76,
  },
  {
    id: 'contentType',
    number: 11,
    title: 'Que tipo de conteúdo você gostaria de criar?',
    options: ['Vlogs', 'Tutoriais', 'Música', 'Comédia'],
    reward: 29.84,
  },
  {
    id: 'socialTime',
    number: 12,
    title: 'Quanto tempo você dedica às redes sociais por dia?',
    options: ['Menos de 1h', '1-3h', '3-5h', 'Mais de 5h'],
    reward: 27.93,
  },
  {
    id: 'socialChallenges',
    number: 13,
    title: 'Você já participou de desafios em redes sociais?',
    options: ['Frequentemente', 'Às vezes', 'Raramente', 'Nunca'],
    reward: 25.82,
  },
  {
    id: 'appMotivation',
    number: 14,
    title: 'O que mais te motiva a usar o app?',
    options: ['Recompensas', 'Conteúdo', 'Comunidade', 'Criar vídeos'],
    reward: 83.71,
  }
];

export default function RewardsScreen() {
  const router = useRouter();
  const [balance, setBalance] = useState(151.47);
  const [currentQuestionIndex, setCurrentQuestionIndex] = useState(0);
  const [answeredQuestions, setAnsweredQuestions] = useState<string[]>([]);
  const [totalEarned, setTotalEarned] = useState(0);
  const [showWithdrawModal, setShowWithdrawModal] = useState(false);

  const currentQuestion = questions[currentQuestionIndex];
  const isQuestionnaireCompleted = answeredQuestions.length === questions.length;

  const handleAnswer = (questionId: string, reward: number) => {
    if (!answeredQuestions.includes(questionId)) {
      const newBalance = balance + reward;
      setBalance(newBalance);
      setTotalEarned(prev => prev + reward);
      setAnsweredQuestions(prev => [...prev, questionId]);
      
      if (currentQuestionIndex < questions.length - 1) {
        setCurrentQuestionIndex(prev => prev + 1);
      }
    }
  };

  const handleContinue = () => {
    Linking.openURL('https://google.com');
  };

  const handleWithdrawPress = () => {
    if (!isQuestionnaireCompleted) {
      setShowWithdrawModal(true);
    }
  };

  return (
    <ScrollView style={styles.container} showsVerticalScrollIndicator={false}>
      <Modal
        visible={showWithdrawModal}
        transparent={true}
        animationType="fade"
        onRequestClose={() => setShowWithdrawModal(false)}
      >
        <View style={styles.modalOverlay}>
          <View style={styles.modalContent}>
            <View style={styles.modalHeader}>
              <View style={styles.alertIconContainer}>
                <AlertCircle size={24} color="#FF4D00" />
              </View>
              <View style={styles.modalHeaderText}>
                <Text style={styles.modalTitle}>QUESTIONÁRIO PENDENTE</Text>
                <Text style={styles.modalText}>
                  Complete o questionário para desbloquear saques.
                </Text>
              </View>
            </View>
            <Text style={styles.modalRewardText}>
              Responda todas as perguntas do questionário para ganhar até R$578,31 e liberar a função de saque.
            </Text>
            <View style={styles.modalButtons}>
              <TouchableOpacity 
                style={styles.modalCloseButton} 
                onPress={() => setShowWithdrawModal(false)}
              >
                <Text style={styles.modalCloseButtonText}>Fechar</Text>
              </TouchableOpacity>
              <TouchableOpacity 
                style={styles.modalActionButton}
                onPress={() => {
                  setShowWithdrawModal(false);
                }}
              >
                <Text style={styles.modalActionButtonText} numberOfLines={1}>Responder agora</Text>
              </TouchableOpacity>
            </View>
          </View>
        </View>
      </Modal>

      <View style={styles.content}>
        <View style={styles.topBar}>
          <View style={styles.balanceSection}>
            <Text style={styles.balanceLabel}>Saldo</Text>
            <Text style={styles.balanceAmount}>R$ {balance.toFixed(2)}</Text>
            <TouchableOpacity 
              style={styles.withdrawButton}
              onPress={handleWithdrawPress}
            >
              <Text style={styles.withdrawText}>sacar</Text>
            </TouchableOpacity>
          </View>

          <View style={styles.goldsSection}>
            <Text style={styles.balanceLabel}>Golds:</Text>
            <Text style={styles.balanceAmount}>
              <View style={styles.coinIconWrapper}>
                <Coins size={16} color="#fff" />
              </View>
              {' '}170
            </Text>
          </View>
        </View>

        <LinearGradient
          colors={['#FF4F01', '#F97216']}
          style={styles.rewardsCard}
        >
          <View style={styles.welcomeContainer}>
            <Text style={styles.welcomeTitle}>Bem-vindo ao Rewards!</Text>
            <Gift size={32} color="#fff" />
          </View>
          <Text style={styles.welcomeDescription}>
            Ganhe recompensas respondendo perguntas simples e completando atividades diárias.
          </Text>

          <View style={styles.earningsBox}>
            <Text style={styles.earningsText}>
              Ganhe até R$628,31 em recompensas hoje!
            </Text>
          </View>
        </LinearGradient>

        <View style={styles.questionCard}>
          {isQuestionnaireCompleted ? (
            <View style={styles.congratulationsContainer}>
              <View style={styles.giftIconContainer}>
                <Gift size={32} color="#FF4F01" />
              </View>
              <Text style={styles.congratulationsTitle}>PARABÉNS!</Text>
              <Text style={styles.congratulationsText}>
                Você completou o questionário e ganhou R${balance.toFixed(2)} em recompensas!
              </Text>
              <TouchableOpacity 
                style={styles.continueButton}
                onPress={handleContinue}
              >
                <Text style={styles.continueButtonText}>Continuar</Text>
              </TouchableOpacity>
            </View>
          ) : (
            <>
              <Text style={styles.questionNumber}>Questão {currentQuestion.number} de {questions.length}</Text>
              <Text style={styles.questionTitle}>{currentQuestion.title}</Text>
              
              <View style={styles.optionsContainer}>
                {currentQuestion.options.map((option, index) => (
                  <TouchableOpacity 
                    key={option} 
                    style={[
                      styles.optionButton,
                      answeredQuestions.includes(currentQuestion.id) && styles.optionButtonDisabled,
                      index < currentQuestion.options.length - 1 && styles.optionButtonMargin
                    ]}
                    onPress={() => handleAnswer(currentQuestion.id, currentQuestion.reward)}
                    disabled={answeredQuestions.includes(currentQuestion.id)}
                  >
                    <Text style={[
                      styles.optionText,
                      answeredQuestions.includes(currentQuestion.id) && styles.optionTextDisabled
                    ]}>
                      {option}
                    </Text>
                  </TouchableOpacity>
                ))}
              </View>

              <View style={styles.rewardContainer}>
                <View style={styles.coinIconWrapper}>
                  <Coins size={16} color="#fff" />
                </View>
                <Text style={styles.rewardText}>
                  {answeredQuestions.includes(currentQuestion.id)
                    ? `Você ganhou R$ ${currentQuestion.reward.toFixed(2)} por esta resposta!`
                    : `Ganhe R$ ${currentQuestion.reward.toFixed(2)} por esta resposta`}
                </Text>
              </View>
            </>
          )}
        </View>
      </View>
    </ScrollView>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#FFF5EC',
  },
  content: {
    paddingTop: 60,
    paddingHorizontal: 20,
    paddingBottom: 40,
  },
  topBar: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'flex-start',
    marginBottom: 40,
  },
  balanceSection: {
    flex: 1,
    marginRight: 20,
  },
  goldsSection: {
    alignItems: 'flex-end',
    minWidth: 120,
  },
  balanceLabel: {
    fontSize: 16,
    color: '#1F2937',
    marginBottom: 4,
  },
  balanceAmount: {
    fontSize: 24,
    fontWeight: '700',
    color: '#1F2937',
    marginBottom: 12,
    flexDirection: 'row',
    alignItems: 'center',
  },
  withdrawButton: {
    backgroundColor: '#FF4D00',
    paddingHorizontal: 20,
    paddingVertical: 8,
    borderRadius: 20,
    alignSelf: 'flex-start',
  },
  withdrawText: {
    color: '#fff',
    fontSize: 14,
    fontWeight: '500',
  },
  coinIconWrapper: {
    width: 24,
    height: 24,
    backgroundColor: '#FFC107',
    borderRadius: 12,
    alignItems: 'center',
    justifyContent: 'center',
    marginRight: 8,
  },
  rewardsCard: {
    borderRadius: 16,
    padding: 24,
    marginBottom: 20,
  },
  welcomeContainer: {
    flexDirection: 'row',
    alignItems: 'center',
    marginBottom: 12,
  },
  welcomeTitle: {
    color: '#fff',
    fontSize: 22,
    fontWeight: '700',
    marginRight: 12,
  },
  welcomeDescription: {
    color: '#fff',
    fontSize: 18,
    lineHeight: 26,
    marginBottom: 24,
  },
  earningsBox: {
    backgroundColor: '#FB8D43',
    borderRadius: 12,
    padding: 16,
  },
  earningsText: {
    color: '#fff',
    fontSize: 16,
    fontWeight: '500',
    textAlign: 'center',
  },
  questionCard: {
    backgroundColor: '#fff',
    borderRadius: 16,
    padding: 24,
    shadowColor: '#000',
    shadowOffset: {
      width: 0,
      height: 2,
    },
    shadowOpacity: 0.1,
    shadowRadius: 3,
    elevation: 3,
  },
  questionNumber: {
    fontSize: 14,
    color: '#6B7280',
    marginBottom: 8,
  },
  questionTitle: {
    fontSize: 20,
    fontWeight: '600',
    color: '#1F2937',
    marginBottom: 20,
  },
  optionsContainer: {
    marginBottom: 20,
  },
  optionButton: {
    backgroundColor: '#F3F4F6',
    paddingVertical: 16,
    paddingHorizontal: 24,
    borderRadius: 12,
    marginBottom: 12,
  },
  optionButtonDisabled: {
    backgroundColor: '#E5E7EB',
    opacity: 0.7,
  },
  optionButtonMargin: {
    marginBottom: 12,
  },
  optionText: {
    fontSize: 16,
    color: '#1F2937',
    textAlign: 'left',
    fontWeight: '500',
  },
  optionTextDisabled: {
    color: '#6B7280',
  },
  rewardContainer: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    backgroundColor: '#F3F4F6',
    padding: 12,
    borderRadius: 12,
  },
  rewardText: {
    fontSize: 16,
    fontWeight: '500',
    color: '#1F2937',
  },
  congratulationsContainer: {
    alignItems: 'center',
    padding: 20,
  },
  giftIconContainer: {
    width: 64,
    height: 64,
    backgroundColor: '#FFF5EC',
    borderRadius: 32,
    alignItems: 'center',
    justifyContent: 'center',
    marginBottom: 16,
  },
  congratulationsTitle: {
    fontSize: 24,
    fontWeight: '700',
    color: '#1F2937',
    marginBottom: 12,
  },
  congratulationsText: {
    fontSize: 18,
    color: '#4B5563',
    textAlign: 'center',
    lineHeight: 24,
    marginBottom: 24,
  },
  continueButton: {
    backgroundColor: '#FF4D00',
    paddingHorizontal: 32,
    paddingVertical: 12,
    borderRadius: 24,
    marginTop: 8,
  },
  continueButtonText: {
    color: '#fff',
    fontSize: 16,
    fontWeight: '600',
  },
  modalOverlay: {
    flex: 1,
    backgroundColor: 'rgba(0, 0, 0, 0.5)',
    justifyContent: 'center',
    alignItems: 'center',
    padding: 20,
  },
  modalContent: {
    backgroundColor: 'white',
    borderRadius: 16,
    padding: 24,
    width: '100%',
    maxWidth: 400,
  },
  modalHeader: {
    flexDirection: 'row',
    alignItems: 'flex-start',
    marginBottom: 24,
  },
  alertIconContainer: {
    width: 48,
    height: 48,
    borderRadius: 24,
    backgroundColor: '#FFF5EC',
    alignItems: 'center',
    justifyContent: 'center',
    marginRight: 12,
  },
  modalHeaderText: {
    flex: 1,
  },
  modalTitle: {
    fontSize: 20,
    fontWeight: '700',
    color: '#1F2937',
    marginBottom: 4,
    textAlign: 'left',
  },
  modalText: {
    fontSize: 16,
    color: '#4B5563',
    textAlign: 'left',
  },
  modalRewardText: {
    fontSize: 14,
    color: '#6B7280',
    marginBottom: 24,
    textAlign: 'left',
  },
  modalButtons: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    gap: 12,
  },
  modalCloseButton: {
    flex: 1,
    paddingVertical: 12,
    paddingHorizontal: 24,
    borderRadius: 24,
    borderWidth: 1,
    borderColor: '#FF4D00',
  },
  modalCloseButtonText: {
    color: '#FF4D00',
    fontSize: 16,
    fontWeight: '600',
    textAlign: 'center',
  },
  modalActionButton: {
    flex: 1,
    backgroundColor: '#FF4D00',
    paddingVertical: 12,
    paddingHorizontal: 24,
    borderRadius: 24,
    minWidth: 140,
  },
  modalActionButtonText: {
    color: 'white',
    fontSize: 16,
    fontWeight: '600',
    textAlign: 'center',
  },
});